"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class FedNowServicesTypedDict(TypedDict):
    receive_payments: bool
    r"""Indicates if the institution can receive instant payments."""
    send_payments: bool
    r"""Indicates if the institution can send instant payments."""
    request_for_payment: bool
    r"""Indicates if the institution can process request for payment messages."""


class FedNowServices(BaseModel):
    receive_payments: Annotated[bool, pydantic.Field(alias="receivePayments")]
    r"""Indicates if the institution can receive instant payments."""

    send_payments: Annotated[bool, pydantic.Field(alias="sendPayments")]
    r"""Indicates if the institution can send instant payments."""

    request_for_payment: Annotated[bool, pydantic.Field(alias="requestForPayment")]
    r"""Indicates if the institution can process request for payment messages."""


try:
    FedNowServices.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class InvoiceStatus(str, Enum):
    DRAFT = "draft"
    UNPAID = "unpaid"
    PAYMENT_PENDING = "payment-pending"
    PAID = "paid"
    OVERDUE = "overdue"
    CANCELED = "canceled"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class IndividualNameUpdateTypedDict(TypedDict):
    first_name: NotRequired[str]
    r"""The individual's first given name."""
    middle_name: NotRequired[str]
    r"""The individual's second given name, if any."""
    last_name: NotRequired[str]
    r"""The individual's family name."""
    suffix: NotRequired[str]
    r"""Suffix of a given name."""


class IndividualNameUpdate(BaseModel):
    first_name: Annotated[Optional[str], pydantic.Field(alias="firstName")] = None
    r"""The individual's first given name."""

    middle_name: Annotated[Optional[str], pydantic.Field(alias="middleName")] = None
    r"""The individual's second given name, if any."""

    last_name: Annotated[Optional[str], pydantic.Field(alias="lastName")] = None
    r"""The individual's family name."""

    suffix: Optional[str] = None
    r"""Suffix of a given name."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["firstName", "middleName", "lastName", "suffix"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    IndividualNameUpdate.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
from moovio_sdk.utils import FieldMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TokenTypeHint(str, Enum):
    r"""The type of token being revoked."""

    ACCESS_TOKEN = "access_token"
    REFRESH_TOKEN = "refresh_token"


class RevokeTokenRequestTypedDict(TypedDict):
    token: str
    r"""The access or refresh token to revoke."""
    token_type_hint: NotRequired[TokenTypeHint]
    r"""The type of token being revoked."""
    client_id: NotRequired[str]
    r"""Client ID can be provided here in the body, or as the Username in HTTP Basic Auth."""
    client_secret: NotRequired[str]
    r"""Client secret can be provided here in the body, or as the Password in HTTP Basic Auth."""


class RevokeTokenRequest(BaseModel):
    token: Annotated[str, FieldMetadata(form=True)]
    r"""The access or refresh token to revoke."""

    token_type_hint: Annotated[Optional[TokenTypeHint], FieldMetadata(form=True)] = None
    r"""The type of token being revoked."""

    client_id: Annotated[Optional[str], FieldMetadata(form=True)] = None
    r"""Client ID can be provided here in the body, or as the Username in HTTP Basic Auth."""

    client_secret: Annotated[Optional[str], FieldMetadata(form=True)] = None
    r"""Client secret can be provided here in the body, or as the Password in HTTP Basic Auth."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["token_type_hint", "client_id", "client_secret"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class RTPServicesTypedDict(TypedDict):
    receive_payments: bool
    r"""Can the institution receive payments"""
    receive_request_for_payment: bool
    r"""Can the institution receive request for payment messages"""


class RTPServices(BaseModel):
    receive_payments: Annotated[bool, pydantic.Field(alias="receivePayments")]
    r"""Can the institution receive payments"""

    receive_request_for_payment: Annotated[
        bool, pydantic.Field(alias="receiveRequestForPayment")
    ]
    r"""Can the institution receive request for payment messages"""


try:
    RTPServices.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .address import Address, AddressTypedDict
from .individualname import IndividualName, IndividualNameTypedDict
from .phonenumber import PhoneNumber, PhoneNumberTypedDict
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class IndividualProfileTypedDict(TypedDict):
    r"""Describes an individual."""

    name: IndividualNameTypedDict
    phone: NotRequired[PhoneNumberTypedDict]
    email: NotRequired[str]
    address: NotRequired[AddressTypedDict]
    birth_date_provided: NotRequired[bool]
    r"""Indicates whether this individual's birth date has been provided."""
    government_id_provided: NotRequired[bool]
    r"""Indicates whether a government ID (SSN, ITIN, etc.) has been provided for this individual."""


class IndividualProfile(BaseModel):
    r"""Describes an individual."""

    name: IndividualName

    phone: Optional[PhoneNumber] = None

    email: Optional[str] = None

    address: Optional[Address] = None

    birth_date_provided: Annotated[
        Optional[bool], pydantic.Field(alias="birthDateProvided")
    ] = None
    r"""Indicates whether this individual's birth date has been provided."""

    government_id_provided: Annotated[
        Optional[bool], pydantic.Field(alias="governmentIDProvided")
    ] = None
    r"""Indicates whether a government ID (SSN, ITIN, etc.) has been provided for this individual."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["phone", "email", "address", "birthDateProvided", "governmentIDProvided"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    IndividualProfile.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .bankaccountpayload import BankAccountPayload, BankAccountPayloadTypedDict
from .mxpayload import MxPayload, MxPayloadTypedDict
from .plaidlinkpayload import PlaidLinkPayload, PlaidLinkPayloadTypedDict
from .plaidpayload import PlaidPayload, PlaidPayloadTypedDict
from typing import Union
from typing_extensions import TypeAliasType


LinkBankAccountTypedDict = TypeAliasType(
    "LinkBankAccountTypedDict",
    Union[
        BankAccountPayloadTypedDict,
        PlaidPayloadTypedDict,
        PlaidLinkPayloadTypedDict,
        MxPayloadTypedDict,
    ],
)


LinkBankAccount = TypeAliasType(
    "LinkBankAccount",
    Union[BankAccountPayload, PlaidPayload, PlaidLinkPayload, MxPayload],
)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ACHPaymentDetailsTypedDict(TypedDict):
    r"""Options for payment links used to collect an ACH payment."""

    company_entry_description: NotRequired[str]
    r"""An optional override of the default NACHA company entry description for a transfer."""
    originating_company_name: NotRequired[str]
    r"""An optional override of the default NACHA company name for a transfer."""


class ACHPaymentDetails(BaseModel):
    r"""Options for payment links used to collect an ACH payment."""

    company_entry_description: Annotated[
        Optional[str], pydantic.Field(alias="companyEntryDescription")
    ] = None
    r"""An optional override of the default NACHA company entry description for a transfer."""

    originating_company_name: Annotated[
        Optional[str], pydantic.Field(alias="originatingCompanyName")
    ] = None
    r"""An optional override of the default NACHA company name for a transfer."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["companyEntryDescription", "originatingCompanyName"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    ACHPaymentDetails.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class SweepStatus(str, Enum):
    ACCRUING = "accruing"
    ACTION_REQUIRED = "action-required"
    CANCELED = "canceled"
    CLOSED = "closed"
    FAILED = "failed"
    PAID = "paid"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .capabilityid import CapabilityID
from .createaccounttype import CreateAccountType
from .createprofile import CreateProfile, CreateProfileTypedDict
from .customersupport import CustomerSupport, CustomerSupportTypedDict
from .mode import Mode
from .settings import Settings, SettingsTypedDict
from .termsofservicepayload import TermsOfServicePayload, TermsOfServicePayloadTypedDict
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CreateAccountTypedDict(TypedDict):
    account_type: CreateAccountType
    profile: CreateProfileTypedDict
    metadata: NotRequired[Dict[str, str]]
    r"""Free-form key-value pair list. Useful for storing information that is not captured elsewhere."""
    terms_of_service: NotRequired[TermsOfServicePayloadTypedDict]
    foreign_id: NotRequired[str]
    r"""Optional alias from a foreign/external system which can be used to reference this resource."""
    customer_support: NotRequired[CustomerSupportTypedDict]
    r"""User-provided information that can be displayed on credit card transactions for customers to use when
    contacting a customer support team. This data is only allowed on a business account.
    """
    settings: NotRequired[SettingsTypedDict]
    r"""User provided settings to manage an account."""
    capabilities: NotRequired[List[CapabilityID]]
    mode: NotRequired[Mode]
    r"""The operating mode for an account."""


class CreateAccount(BaseModel):
    account_type: Annotated[CreateAccountType, pydantic.Field(alias="accountType")]

    profile: CreateProfile

    metadata: Optional[Dict[str, str]] = None
    r"""Free-form key-value pair list. Useful for storing information that is not captured elsewhere."""

    terms_of_service: Annotated[
        Optional[TermsOfServicePayload], pydantic.Field(alias="termsOfService")
    ] = None

    foreign_id: Annotated[Optional[str], pydantic.Field(alias="foreignID")] = None
    r"""Optional alias from a foreign/external system which can be used to reference this resource."""

    customer_support: Annotated[
        Optional[CustomerSupport], pydantic.Field(alias="customerSupport")
    ] = None
    r"""User-provided information that can be displayed on credit card transactions for customers to use when
    contacting a customer support team. This data is only allowed on a business account.
    """

    settings: Optional[Settings] = None
    r"""User provided settings to manage an account."""

    capabilities: Optional[List[CapabilityID]] = None

    mode: Optional[Mode] = None
    r"""The operating mode for an account."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "metadata",
                "termsOfService",
                "foreignID",
                "customerSupport",
                "settings",
                "capabilities",
                "mode",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    CreateAccount.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from moovio_sdk.types import BaseModel
import pydantic
from typing_extensions import Annotated, TypedDict


class WebhookBillingStatementCreatedTypedDict(TypedDict):
    statement_id: str


class WebhookBillingStatementCreated(BaseModel):
    statement_id: Annotated[str, pydantic.Field(alias="statementID")]


try:
    WebhookBillingStatementCreated.model_rebuild()
except NameError:
    pass



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cardbrand import CardBrand
from .cardexpiration import CardExpiration, CardExpirationTypedDict
from .cardtype import CardType
from moovio_sdk.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ApplePayResponseTypedDict(TypedDict):
    r"""Describes an Apple Pay token on a Moov account."""

    brand: CardBrand
    r"""The card brand."""
    card_type: CardType
    r"""The type of the card."""
    card_display_name: str
    r"""User-friendly name of the tokenized card returned by Apple.

    It usually contains the brand and the last four digits of the underlying card.
    There is no standard format.
    """
    fingerprint: str
    r"""Uniquely identifies a linked payment card or token.
    For Apple Pay, the fingerprint is based on the tokenized card number and may vary based on the user's device.
    This field can be used to identify specific payment methods across multiple accounts on your platform.
    """
    expiration: CardExpirationTypedDict
    r"""The expiration date of the card or token."""
    dynamic_last_four: str
    r"""The last four digits of the Apple Pay token, which may differ from the tokenized card's last four digits."""
    issuer_country: NotRequired[str]
    r"""Country where the underlying card was issued."""


class ApplePayResponse(BaseModel):
    r"""Describes an Apple Pay token on a Moov account."""

    brand: CardBrand
    r"""The card brand."""

    card_type: Annotated[CardType, pydantic.Field(alias="cardType")]
    r"""The type of the card."""

    card_display_name: Annotated[str, pydantic.Field(alias="cardDisplayName")]
    r"""User-friendly name of the tokenized card returned by Apple.

    It usually contains the brand and the last four digits of the underlying card.
    There is no standard format.
    """

    fingerprint: str
    r"""Uniquely identifies a linked payment card or token.
    For Apple Pay, the fingerprint is based on the tokenized card number and may vary based on the user's device.
    This field can be used to identify specific payment methods across multiple accounts on your platform.
    """

    expiration: CardExpiration
    r"""The expiration date of the card or token."""

    dynamic_last_four: Annotated[str, pydantic.Field(alias="dynamicLastFour")]
    r"""The last four digits of the Apple Pay token, which may differ from the tokenized card's last four digits."""

    issuer_country: Annotated[Optional[str], pydantic.Field(alias="issuerCountry")] = (
        None
    )
    r"""Country where the underlying card was issued."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["issuerCountry"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k, serialized.get(n))

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    ApplePayResponse.model_rebuild()
except NameError:
    pass
